@@ -6,6 +6,8 @@ KW_EXPIRATION = 'exp'
 KW_NFB = 'nbf'
 KW_IAT = 'iat'
 KW_TYPE = 'type'
+KW_CONTEXT = 'context'
+KW_DATA = 'data'
 
 KW_JWT_ALGORITHM = 'JWT_ALGORITHM'
 KW_JWT_SECRET_KEY = 'JWT_SECRET_KEY'
@@ -18,18 +20,17 @@ FORBIDDEN_MESSAGE = 'Frobidden'
 INVALID_SESSION_MESSAGE = 'Invalid session'
 INVALID_API_KEY_MESSAGE = 'Invalid apiKey'
 
-KW_CONTEXT = 'context'
-KW_DATA = 'data'
-
-
 ACCESS_VALUE_TYPE = 'access'
 REFRESH_VALUE_TYPE = 'refresh'
 
-
-DEFAULT_JWT_SECURITY_ALGORITHM = "HS256" ###- HS512
-DEFAULT_JWT_AUTHORIZATION_HEADER_NAME = "Authorization"
-DEFAULT_JWT_AUTHORIZATION_HEADER_TYPE = "Bearer"
-
 DEFAULT_JWT_SESSION_ALGORITHM = "HS256" ###- HS512
 DEFAULT_JWT_SESSION_HEADER_NAME = "Context"
 DEFAULT_JWT_SESSION_HEADER_TYPE = "Bearer"
+
+DEFAULT_JWT_API_KEY_ALGORITHM = "HS256" ###- HS512
+DEFAULT_JWT_API_KEY_HEADER_NAME = "Context"
+DEFAULT_JWT_API_KEY_HEADER_TYPE = "Bearer"
+
+DEFAULT_JWT_SECURITY_ALGORITHM = "HS256" ###- HS512
+DEFAULT_JWT_SECURITY_HEADER_NAME = "Authorization"
+DEFAULT_JWT_SECURITY_HEADER_TYPE = "Bearer"
